/***
 * Juliac
 * Copyright (C) 2011-2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac;

import java.util.List;
import java.util.logging.Logger;

import org.apache.maven.artifact.DependencyResolutionRequiredException;
import org.apache.maven.model.Build;
import org.apache.maven.model.Resource;

/**
 * Juliac Maven pluging for the generate-sources phase.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 * @since 2.3
 * 
 * @goal compile
 * @phase generate-sources
 * @requiresDependencyResolution runtime
 */
public class CompileJuliacMojo extends AbstractJuliacMojo {

    /**
     * The directory containing the generated source code.
     * Default value: <code>target/generated-sources/juliac</code>.
     * 
     * @parameter
     */
    private String gensrc;
    
    /**
     * The directory containing the compiled source code.
     * Default value: <code>target/classes</code>.
     * 
     * @parameter
     */
    private String genclass;

    
    // ---------------------------------------------------------------------
    // Abstract method implementation
    // ---------------------------------------------------------------------
    
    protected String getGenSrc() {
        String gensrc = Utils.trimHeadingAndTrailingBlanks(this.gensrc);
        if( gensrc == null ) {
            gensrc = "target/generated-sources/juliac";
        }
    	return gensrc;
    }
    
    protected String getGenClass() {
        String genclass = Utils.trimHeadingAndTrailingBlanks(this.genclass);
        if( genclass == null ) {
            genclass = "target/classes";
        }
        return genclass;
    }
    
    protected void addResources( JuliacMojoClassPathElements cpe ) {
        Build build = project.getBuild();
        List<Resource> resources = build.getResources();
        cpe.addResources(resources);    	
    }
    
    protected void addPaths( JuliacMojoClassPathElements cpe )
    throws DependencyResolutionRequiredException {
        List<String> list = project.getCompileClasspathElements();
        cpe.addPaths(list);
    }
    
    protected void addSourceRoot( String genDirName, Logger logger ) {
        project.addCompileSourceRoot(genDirName);
        logger.fine("Juliac compile source root: "+genDirName);    	
    }
}
