/***
 * Juliac
 * Copyright (C) 2007-2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac;

import java.util.List;

import org.objectweb.fractal.api.factory.InstantiationException;
import org.objectweb.fractal.api.type.ComponentType;
import org.objectweb.fractal.julia.type.BasicComponentType;

/**
 * This class implements the configuration parameters for the <component> tag
 * of the Juliac MOJO. The <component> tag specifies the interface types, the
 * controller descriptor and the content descriptor of a component whose code is
 * to be generated by Juliac.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 */
public class Component {

    /**
     * The list of interface types.
     * 
     * @parameter
     */
    private List<InterfaceType> interfaceTypes;
    
    /**
     * The controller descriptor.
     * 
     * @parameter
     */
    private String controllerDesc;
    
    /**
     * The content descriptor.
     * 
     * @parameter
     */
    private String contentDesc;

    
    // ---------------------------------------------------------------------
    // Getters
    // ---------------------------------------------------------------------
    
    public String getControllerDesc() {
        return Utils.trimHeadingAndTrailingBlanks(controllerDesc);
    }
    
    public String getContentDesc() {
        return contentDesc = Utils.trimHeadingAndTrailingBlanks(this.contentDesc);
    }
    
    /**
     * Return the Fractal component type corresponding to the data stored in the
     * current instance.
     */
    public ComponentType toFractalComponentType()
    throws InstantiationException {
        
    	if( interfaceTypes == null ) {
    		return null;
    	}
    	
        org.objectweb.fractal.api.type.InterfaceType[] its =
            new org.objectweb.fractal.api.type.InterfaceType[
                 interfaceTypes.size() ];
        int i = 0;
        for (InterfaceType interfaceType : interfaceTypes) {
            its[i] = interfaceType.toFractalInterfaceType();
            i++;
        }
        ComponentType ct = new BasicComponentType(its);
        
        return ct;
    }
    
    @Override
    public String toString() {
        
        StringBuffer sb = new StringBuffer();
        sb.append('[');
        if( interfaceTypes == null ) {
        	sb.append("null");
        }
        else {
            boolean first = true;
            for (InterfaceType it : interfaceTypes) {
                if(first) {first=false;} else {sb.append(',');}
                sb.append(it.toString());
            }
        }
        sb.append("]:");
        sb.append(controllerDesc);
        sb.append(":");
        sb.append(contentDesc);
        
        return sb.toString();
    }
}
