/***
 * Juliac
 * Copyright (C) 2007-2012 Inria, Univ. Lille 1
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@ow2.org
 *
 * Author: Lionel Seinturier
 */

package org.objectweb.fractal.juliac;

import org.objectweb.fractal.julia.type.BasicInterfaceType;

/**
 * This class implements the configuration parameters for the <interfaceType>
 * tag of the Juliac MOJO. The <interfaceType> tag specifies one of the
 * interface types of a component whose code is to be generated by Juliac.
 * 
 * @author Lionel Seinturier <Lionel.Seinturier@univ-lille1.fr>
 */
public class InterfaceType {

    /**
     * The interface name.
     * 
     * @parameter
     */
    private String name;
    
    /**
     * The interface signature.
     * 
     * @parameter
     */
    private String signature;
    
    /**
     * true if the interface is client.
     * 
     * @parameter
     */
    private boolean isClient;
    
    /**
     * true if the interface is optional.
     * 
     * @parameter
     */
    private boolean isOptional;
    
    /**
     * true if the interface is collection.
     * 
     * @parameter
     */
    private boolean isCollection;
    
    /**
     * Return the Fractal interface type corresponding to the data stored in the
     * current instance.
     */
    public org.objectweb.fractal.api.type.InterfaceType toFractalInterfaceType() {
        String name = Utils.trimHeadingAndTrailingBlanks(this.name);
        String signature = Utils.trimHeadingAndTrailingBlanks(this.signature);
        org.objectweb.fractal.api.type.InterfaceType it =
            new BasicInterfaceType(name,signature,isClient,isOptional,isCollection);
        return it;
    }

    @Override
    public String toString() {
        
        StringBuffer sb = new StringBuffer();
        sb.append(name);
        sb.append('/');
        sb.append(signature);
        sb.append('/');
        sb.append(isClient);
        sb.append('/');
        sb.append(isOptional);
        sb.append('/');
        sb.append(isCollection);
        
        return sb.toString();
    }
}
